pub enum Error {
Signal,
Invalid,
Exception(String),
Error(String),
DeserializationError(Error),
InternalError,
}Expand description
The error type used when attempting to deserialize a crate::Packet.
Variants
Signal
Tried to deserialize a Signal packet.
Invalid
Invalid payload.
Exception(String)
Packet was an Exception.
Error(String)
Packet was an Error.
DeserializationError(Error)
An error deserializing from MessagePack.
InternalError
An Internal error given when the packet contained a message not destined for a consumer.